/* Sistemas Integrados TECNISA
   Compras e Suprimentos

Nome: LIMPA_ITEMCOLE_MONTAGEM

Descrio:
Limpa os campos que relacionam a itemcole a uma lista de preos na
montagem da lista de preos para que os registros sejam relacionados
a outra lista
*/

IF EXISTS (SELECT * FROM sysobjects O, sysusers U
            WHERE
            o.name = 'LIMPA_ITEMCOLE_MONTAGEM'  and
            type = 'P'                  and
            u.uid = o.uid               and
            u.name = USER)
   DROP PROCEDURE LIMPA_ITEMCOLE_MONTAGEM;
GO

CREATE PROCEDURE LIMPA_ITEMCOLE_MONTAGEM
   (@P_CDFILIAL     VARCHAR(4),
    @P_DTINIVALITM  DATETIME,
    @P_DTFINVALITM  DATETIME,
    @P_CDREGIAO     VARCHAR(3),
    @P_TCDREGIAO    VARCHAR(1),
    @P_CDPRODINI    VARCHAR(30),
    @P_CDPRODFIN    VARCHAR(30),
    @P_TPRODUTO     VARCHAR(1),
    @P_CARGCOT      VARCHAR(1),
    @P_CDOPERADOR   VARCHAR(12),
    @P_COINCIDE     VARCHAR(1),
    @P_NRSEQPRELIST VARCHAR(10),
    @P_PREENCHETAB  VARCHAR(1),
    @P_ROWSAFFECT DOUBLE PRECISION OUTPUT
    )
AS
DECLARE @V_CONT_COMMIT DOUBLE PRECISION;
DECLARE @V_QTDE_COMMIT DOUBLE PRECISION;
DECLARE @V_CDREGIAO    VARCHAR(120);
DECLARE @V_TCDREGIAO   CHAR(1);
DECLARE @V_ERROR       VARCHAR(2000);

DECLARE @V_ITEMCOLE_TMP_CDFILIAL    VARCHAR(4);
DECLARE @V_ITEMCOLE_TMP_NRCOLEPRECO VARCHAR(10);
DECLARE @V_ITEMCOLE_TMP_CDMARCA     VARCHAR(5);
DECLARE @V_ITEMCOLE_TMP_CDREGIAO    VARCHAR(3);
DECLARE @V_ITEMCOLE_TMP_CDFORNECED  VARCHAR(21);
DECLARE @V_ITEMCOLE_TMP_CDPRODUTO   VARCHAR(10);

BEGIN
   SET @V_CONT_COMMIT = 0;
   SET @V_QTDE_COMMIT = 1000;

   SET @V_CDREGIAO    = @P_CDREGIAO;
   SET @V_TCDREGIAO   = @P_TCDREGIAO;
   IF @P_PREENCHETAB = 'S' BEGIN
      IF @P_COINCIDE = 'S' BEGIN
         INSERT INTO ITEMCOLE_TMP (CDFILIALTMP,NRCOLEPRECOTMP,CDMARCATMP,CDREGIAOTMP,CDFORNECEDTMP,CDPRODUTOTMP, NRSEQPRELISTTMP)
         SELECT
            ITEMCOLE.CDFILIAL,
            ITEMCOLE.NRCOLEPRECO,
            ITEMCOLE.CDMARCA,
            ITEMCOLE.CDREGIAO,
            ITEMCOLE.CDFORNECED,
            ITEMCOLE.CDPRODUTO,
            @P_NRSEQPRELIST
         FROM ITEMCOLE
         WHERE ITEMCOLE.CDFILIAL    = @P_CDFILIAL
           AND ITEMCOLE.DTINIVALITM = @P_DTINIVALITM
           AND ITEMCOLE.DTFINVALITM = @P_DTFINVALITM
           AND ITEMCOLE.NRSEQPRELIST IS NOT NULL
           AND (CHARINDEX(ITEMCOLE.CDREGIAO, @P_CDREGIAO) <> 0 OR @P_TCDREGIAO = 'T')
           AND EXISTS (SELECT 1
                       FROM PRODUTO
                       WHERE (PRODUTO.CDARVPROD BETWEEN @P_CDPRODINI AND @P_CDPRODFIN OR @P_TPRODUTO = 'T')
                         AND  ITEMCOLE.CDPRODUTO = PRODUTO.CDPRODUTO)
           AND EXISTS (SELECT 1
                       FROM COLETAPR
                       WHERE (COLETAPR.IDTIPCOLREG IN ('G','W', 'E') OR @P_CARGCOT = 'T')
                         AND (COLETAPR.CDOPERADOR  = @P_CDOPERADOR)
                         AND (COLETAPR.CDFILIAL    = ITEMCOLE.CDFILIAL)
                         AND (COLETAPR.NRCOLEPRECO = ITEMCOLE.NRCOLEPRECO))
           AND EXISTS (SELECT 1
                       FROM PRODCOMP, PRODUTO PRCOMP, PRODUTO PRODCOT
                       WHERE ITEMCOLE.CDPRODUTO  = PRODCOT.CDPRODUTO
                        AND  PRODCOMP.CDPRODUTO  = PRCOMP.CDPRODUTO
                        AND  PRODCOMP.CDOPERADOR = @P_CDOPERADOR
                        AND  PRODCOT.CDARVPROD LIKE PRCOMP.CDARVPROD + '%')
           AND NOT EXISTS (SELECT 1
                           FROM ITMPREVLIST
                           WHERE ITMPREVLIST.CDFILIAL = ITEMCOLE.CDFILIAL
                             AND ITMPREVLIST.NRCOLEPRECO = ITEMCOLE.NRCOLEPRECO
                             AND ITMPREVLIST.CDMARCA = ITEMCOLE.CDMARCA
                             AND ITMPREVLIST.CDREGIAO = ITEMCOLE.CDREGIAO
                             AND ITMPREVLIST.CDFORNECED = ITEMCOLE.CDFORNECED
                             AND ITMPREVLIST.CDPRODUTO = ITEMCOLE.CDPRODUTO
                             AND ITMPREVLIST.NRSEQPRELIST = @P_NRSEQPRELIST
                             AND ITMPREVLIST.IDITMLISTJAMONT = 'S');
         SET @P_ROWSAFFECT = @@ROWCOUNT;
      END
      ELSE BEGIN
         INSERT INTO ITEMCOLE_TMP (CDFILIALTMP,NRCOLEPRECOTMP,CDMARCATMP,CDREGIAOTMP,CDFORNECEDTMP,CDPRODUTOTMP, NRSEQPRELISTTMP)
         SELECT
            ITEMCOLE.CDFILIAL,
            ITEMCOLE.NRCOLEPRECO,
            ITEMCOLE.CDMARCA,
            ITEMCOLE.CDREGIAO,
            ITEMCOLE.CDFORNECED,
            ITEMCOLE.CDPRODUTO,
            @P_NRSEQPRELIST
         FROM ITEMCOLE
         WHERE ITEMCOLE.CDFILIAL    = @P_CDFILIAL
           AND ITEMCOLE.DTINIVALITM <= @P_DTFINVALITM
           AND ITEMCOLE.DTFINVALITM >= @P_DTINIVALITM
           AND ITEMCOLE.NRSEQPRELIST IS NOT NULL
           AND (CHARINDEX(ITEMCOLE.CDREGIAO, @P_CDREGIAO) <> 0 OR @P_TCDREGIAO = 'T')
           AND EXISTS (SELECT 1
                       FROM PRODUTO
                       WHERE (PRODUTO.CDARVPROD BETWEEN @P_CDPRODINI AND @P_CDPRODFIN OR @P_TPRODUTO = 'T')
                         AND  ITEMCOLE.CDPRODUTO = PRODUTO.CDPRODUTO)
           AND EXISTS (SELECT 1
                       FROM COLETAPR
                       WHERE (COLETAPR.IDTIPCOLREG IN ('G','W', 'E') OR @P_CARGCOT = 'T')
                         AND (COLETAPR.CDOPERADOR  = @P_CDOPERADOR)
                         AND (COLETAPR.CDFILIAL    = ITEMCOLE.CDFILIAL)
                         AND (COLETAPR.NRCOLEPRECO = ITEMCOLE.NRCOLEPRECO))
           AND EXISTS (SELECT 1
                       FROM PRODCOMP, PRODUTO PRCOMP, PRODUTO PRODCOT
                       WHERE ITEMCOLE.CDPRODUTO  = PRODCOT.CDPRODUTO
                        AND  PRODCOMP.CDPRODUTO  = PRCOMP.CDPRODUTO
                        AND  PRODCOMP.CDOPERADOR = @P_CDOPERADOR
                        AND  PRODCOT.CDARVPROD LIKE PRCOMP.CDARVPROD + '%')
           AND NOT EXISTS (SELECT 1
                           FROM ITMPREVLIST
                           WHERE ITMPREVLIST.CDFILIAL = ITEMCOLE.CDFILIAL
                             AND ITMPREVLIST.NRCOLEPRECO = ITEMCOLE.NRCOLEPRECO
                             AND ITMPREVLIST.CDMARCA = ITEMCOLE.CDMARCA
                             AND ITMPREVLIST.CDREGIAO = ITEMCOLE.CDREGIAO
                             AND ITMPREVLIST.CDFORNECED = ITEMCOLE.CDFORNECED
                             AND ITMPREVLIST.CDPRODUTO = ITEMCOLE.CDPRODUTO
                             AND ITMPREVLIST.NRSEQPRELIST = @P_NRSEQPRELIST
                             AND ITMPREVLIST.IDITMLISTJAMONT = 'S');
         SET @P_ROWSAFFECT = @@ROWCOUNT;
      END;
   END;
   DECLARE C_ITEMCOLE_TMP CURSOR FOR  --Declarao do cursor
      SELECT
         ITEMCOLE_TMP.CDFILIALTMP CDFILIAL,
         ITEMCOLE_TMP.NRCOLEPRECOTMP NRCOLEPRECO,
         ITEMCOLE_TMP.CDMARCATMP CDMARCA,
         ITEMCOLE_TMP.CDREGIAOTMP CDREGIAO,
         ITEMCOLE_TMP.CDFORNECEDTMP CDFORNECED,
         ITEMCOLE_TMP.CDPRODUTOTMP CDPRODUTO
      FROM ITEMCOLE_TMP
      WHERE ITEMCOLE_TMP.CDFILIALTMP = @P_CDFILIAL
        AND ITEMCOLE_TMP.NRSEQPRELISTTMP = @P_NRSEQPRELIST
   OPEN C_ITEMCOLE_TMP;
   FETCH NEXT FROM C_ITEMCOLE_TMP INTO @V_ITEMCOLE_TMP_CDFILIAL,
                                       @V_ITEMCOLE_TMP_NRCOLEPRECO,
                                       @V_ITEMCOLE_TMP_CDMARCA,
                                       @V_ITEMCOLE_TMP_CDREGIAO,
                                       @V_ITEMCOLE_TMP_CDFORNECED,
                                       @V_ITEMCOLE_TMP_CDPRODUTO;
   WHILE (@@FETCH_STATUS = 0)  BEGIN
      UPDATE ITEMCOLE
      SET IDITMLISPREC = 'N',
          IDPRECALT    = 'N',
          NRSEQPRELIST = NULL
      WHERE CDFILIAL    = @V_ITEMCOLE_TMP_CDFILIAL
        AND NRCOLEPRECO = @V_ITEMCOLE_TMP_NRCOLEPRECO
        AND CDMARCA     = @V_ITEMCOLE_TMP_CDMARCA
        AND CDREGIAO    = @V_ITEMCOLE_TMP_CDREGIAO
        AND CDFORNECED  = @V_ITEMCOLE_TMP_CDFORNECED
        AND CDPRODUTO   = @V_ITEMCOLE_TMP_CDPRODUTO;

      DELETE FROM ITEMCOLE_TMP
      WHERE CDFILIALTMP     = @V_ITEMCOLE_TMP_CDFILIAL
        AND NRCOLEPRECOTMP  = @V_ITEMCOLE_TMP_NRCOLEPRECO
        AND CDMARCATMP      = @V_ITEMCOLE_TMP_CDMARCA
        AND CDREGIAOTMP     = @V_ITEMCOLE_TMP_CDREGIAO
        AND CDFORNECEDTMP   = @V_ITEMCOLE_TMP_CDFORNECED
        AND CDPRODUTOTMP    = @V_ITEMCOLE_TMP_CDPRODUTO
        AND NRSEQPRELISTTMP = @P_NRSEQPRELIST;

      SET @V_CONT_COMMIT = @V_CONT_COMMIT + 1;
      IF (@V_CONT_COMMIT >= @V_QTDE_COMMIT) BEGIN
         BREAK;
      END;
      FETCH NEXT FROM C_ITEMCOLE_TMP INTO @V_ITEMCOLE_TMP_CDFILIAL,
                                          @V_ITEMCOLE_TMP_NRCOLEPRECO,
                                          @V_ITEMCOLE_TMP_CDMARCA,
                                          @V_ITEMCOLE_TMP_CDREGIAO,
                                          @V_ITEMCOLE_TMP_CDFORNECED,
                                          @V_ITEMCOLE_TMP_CDPRODUTO;
   END;
   IF @P_PREENCHETAB = 'S' BEGIN
      IF @P_ROWSAFFECT > @V_CONT_COMMIT BEGIN
         SET @P_ROWSAFFECT = @P_ROWSAFFECT - @V_CONT_COMMIT;
      END
      ELSE BEGIN
         SET @P_ROWSAFFECT = 0;
      END;
   END
   ELSE BEGIN
      SET @P_ROWSAFFECT = @V_CONT_COMMIT;
   END;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'LIMPA_ITEMCOLE_MONTAGEM','5.05.003';
GO

